<?php
/**
 * @package SS_PiwikTracking\Views\Backend
 */

if ( !defined( 'SS_PIWIKTRACKING_VERSION' ) ) {
	exit;
}

/**
 * Backend options class.
 *
 * Displays the backend interface.
 *
 * @since 1.0.0
 */
abstract class SS_PiwikTracking_ViewBackendSettings {
	/**
	 * Set up Wordpress.
	 *
	 * Prepares Wordpress for the settings page.
	 *
	 * @see SS_PiwikTracking_ControllerBackend::add_settings_link(),SS_PiwikTracking_ControllerBackend::output_settings_page(),SS_PiwikTracking_ControllerBackend::output_settings_section(),SS_PiwikTracking_ControllerBackend::output_settings_field()
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function set_up() {
		add_filter( 'plugin_action_links_' . SS_PIWIKTRACKING_SLUG . '/' . SS_PIWIKTRACKING_SLUG . '.php', array( 'SS_PiwikTracking_ControllerBackend', 'add_settings_link' ) );

		add_options_page( __( 'Piwik tracking settings', 'SS_PiwikTracking' ), __( 'Piwik tracking', 'SS_PiwikTracking' ), 'manage_options', SS_PIWIKTRACKING_SLUG, array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_page' ) );

		add_settings_section( 'general', ''/*__( 'General', 'SS_PiwikTracking' )*/, array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_section' ) , SS_PIWIKTRACKING_SLUG );
		add_settings_field( 'SS_PiwikTracking-enable', __( 'Enable', 'SS_PiwikTracking' ), array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_field' ), SS_PIWIKTRACKING_SLUG, 'general', array( 'label_for' => 'SS_PiwikTracking-enable' ) );
		add_settings_field( 'SS_PiwikTracking-address', __( 'Address', 'SS_PiwikTracking' ), array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_field' ), SS_PIWIKTRACKING_SLUG, 'general', array( 'label_for' => 'SS_PiwikTracking-address' ) );
		add_settings_field( 'SS_PiwikTracking-ssl_compat', __( 'SSL compatibility', 'SS_PiwikTracking' ), array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_field' ), SS_PIWIKTRACKING_SLUG, 'general', array( 'label_for' => 'SS_PiwikTracking-ssl_compat' ) );
		add_settings_field( 'SS_PiwikTracking-site_id', __( 'Site Id', 'SS_PiwikTracking' ), array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_field' ), SS_PIWIKTRACKING_SLUG, 'general', array( 'label_for' => 'SS_PiwikTracking-site_id') );
		add_settings_field( 'SS_PiwikTracking-log_usernames', __( 'Log usernames', 'SS_PiwikTracking' ), array( 'SS_PiwikTracking_ControllerBackend', 'output_settings_field' ), SS_PIWIKTRACKING_SLUG, 'general', array( 'label_for' => 'SS_PiwikTracking-log_usernames' ) );
	}

	/**
	 * Generate settings link.
	 *
	 * Returns the HTML code of the settings link.
	 *
	 * @since 1.0.0
	 *
	 * @param string $url The URL.
	 * @return string The code.
	 */
	public static function get_settings_link( $url ) {
		return '<a href="' . $url . '"> '.__( 'Settings', 'SS_PiwikTracking' ).' </a>';
	}

	/**
	 * Output settings page.
	 *
	 * Outputs the HTML code of the settings page.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function output_page() {
?>
<div id="SS_PiwikTracking" class="wrap"><?php screen_icon(); ?>
<h2><?php _e( 'Piwik tracking settings', 'SS_PiwikTracking' ); ?></h2>
<form method="post" action="options.php">
<?php settings_fields( 'SS_PiwikTracking' ); ?>
<?php do_settings_sections( SS_PIWIKTRACKING_SLUG ); ?>
<?php submit_button(); ?>
</form>
</div>
<?php
	}

	/**
	 * Output form fields.
	 *
	 * Depending on the arguments received, outputs a field for the settings form.
	 * It gets the saved options to display the field accordingly.
	 *
	 * @since 1.0.0
	 *
	 * @param string $name The name of the option.
	 * @param mixed $value The value of the option.
	 * @return void
	 */
	public static function output_field( $name, $value ) {
		switch ( $name ) {
			case 'enable':
?>
<input id="SS_PiwikTracking-<?php echo $name; ?>" name="SS_PiwikTracking[<?php echo $name; ?>]" type="checkbox" value="1"<?php echo $value ? ' checked="checked"' : ''; ?> />
<p class="description"><?php _e( 'Enable Piwik tracking?', 'SS_PiwikTracking' ); ?></p>
<?php
				break;
			case 'address':
?>
<input id="SS_PiwikTracking-<?php echo $name; ?>" name="SS_PiwikTracking[<?php echo $name; ?>]" type="text" class="regular-text" value="<?php echo $value; ?>" />
<p class="description"><?php printf( __( 'The address of your Piwik install, without protocol. (e.g. %s/piwik)', 'SS_PiwikTracking' ), $_SERVER["SERVER_NAME"] ); ?></p>
<?php
				break;
			case 'ssl_compat':
?>
<input id="SS_PiwikTracking-<?php echo $name; ?>" name="SS_PiwikTracking[<?php echo $name; ?>]" type="checkbox" value="1"<?php echo $value ? ' checked="checked"' : ''; ?> />
<p class="description"><?php _e( 'Does your Piwik install support SSL access? (HTTP<b>S</b>://)', 'SS_PiwikTracking' ); ?></p>
<?php
				break;
			case 'site_id':
?>
<input id="SS_PiwikTracking-<?php echo $name; ?>" name="SS_PiwikTracking[<?php echo $name; ?>]" type="text" class="regular-text" value="<?php echo $value; ?>" />
<p class="description"><?php _e( 'The id of this site on your Piwik install.', 'SS_PiwikTracking' ); ?></p>
<?php
				break;
			case 'log_usernames':
?>
<input id="SS_PiwikTracking-<?php echo $name; ?>" name="SS_PiwikTracking[<?php echo $name; ?>]" type="checkbox" value="1"<?php echo $value ? ' checked="checked"' : ''; ?> />
<p class="description"><?php _e( 'Do you want Piwik to log the usernames of logged in users?', 'SS_PiwikTracking' ); ?></p>
<?php
				break;
			default:
				break;
		}
	}

	/**
	 * Output error messages.
	 *
	 * Sets Wordpress to display an error message according to the supplied option id.
	 *
	 * @since 1.0.0
	 *
	 * @param string $name The name of the option.
	 * @return void
	 */
	public static function output_error( $name ) {
		switch ( $name ) {
			case 'address':
				add_settings_error( 'SS_PiwikTracking-address', 'invalid-SS_PiwikTracking-address', __( 'The "Address" seems invalid.<br />Please check this field and try again.', 'SS_PiwikTracking' ) );
				break;
			case 'site_id':
				add_settings_error( 'SS_PiwikTracking-site_id', 'invalid-SS_PiwikTracking-site_id', __( '"Site Id" must be an integer number greater than zero.<br />Please check this field and try again.', 'SS_PiwikTracking' ) );
				break;
			default:
				break;
		}
	}
}
